@@ -123,6 +123,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Cruzeño"                                       => "Cruzeno",
    "Cupeño"                                        => "Cupeno",
    "Côông"                                         => "Coong",
+   "Daatsʼíin"                                     => "Daats'iin",
    "Daloa Bété"                                    => "Daloa Bete",
    "Dangaléat"                                     => "Dangaleat",
    "Dení"                                          => "Deni",
@@ -245,6 +246,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Magdalena Peñasco Mixtec"                      => "Magdalena Penasco Mixtec",
    "Magɨyi"                                        => "Magyi",
    "Mainfränkisch"                                 => "Mainfrankisch",
+   "Máku"                                          => "Maku",
    "Makuráp"                                       => "Makurap",
    "Maléku Jaíka"                                  => "Maleku Jaika",
    "Malê"                                          => "Male",
@@ -301,6 +303,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Ojitlán Chinantec"                             => "Ojitlan Chinantec",
    "Old Provençal (to 1500)"                       => "Old Provencal (to 1500)",
    "Orejón"                                        => "Orejon",
+   "Övdalian"                                      => "Ovdalian",
    "Ozumacín Chinantec"                            => "Ozumacin Chinantec",
    "Paicî"                                         => "Paici",
    "Pakaásnovos"                                   => "Pakaasnovos",
@@ -338,6 +341,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Quiché"                                        => "Quiche",
    "Quioquitani-Quierí Zapotec"                    => "Quioquitani-Quieri Zapotec",
    "Rayón Zoque"                                   => "Rayon Zoque",
+   "Rāziḥī"                                        => "Razihi",
    "Resígaro"                                      => "Resigaro",
    "Rincón Zapotec"                                => "Rincon Zapotec",
    "Réunion Creole French"                         => "Reunion Creole French",
@@ -462,6 +466,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Yanomámi"                                      => "Yanomami",
    "Yaouré"                                        => "Yaoure",
    "Yarí"                                          => "Yari",
+   "Yaroamë"                                       => "Yaroame",
    "Yawalapití"                                    => "Yawalapiti",
    "Yocoboué Dida"                                 => "Yocoboue Dida",
    "Yosondúa Mixtec"                               => "Yosondua Mixtec",
